@@ -5,6 +5,8 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+// clazy:excludeall=overloaded-signal
+
 #pragma once
 
 #include <Libkdepim/MultiplyingLine>
@@ -117,12 +119,12 @@ private:
     void dataFromFields();
     void fieldsFromData();
 
-    AttendeeComboBox *mRoleCombo = nullptr;
-    AttendeeComboBox *mStateCombo = nullptr;
-    AttendeeComboBox *mResponseCombo = nullptr;
-    AttendeeLineEdit *mEdit = nullptr;
+    AttendeeComboBox *const mRoleCombo;
+    AttendeeComboBox *const mStateCombo;
+    AttendeeComboBox *const mResponseCombo;
+    AttendeeLineEdit *const mEdit;
     QSharedPointer<AttendeeData> mData;
     QString mUid;
-    bool mModified;
+    bool mModified = false;
 };
 }
